==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/soda/classes/wrapper/untyped/STFloatWU.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o;
using com.db4o.query;
using com.db4o.test.soda;
namespace com.db4o.test.soda.classes.wrapper.untyped {

   public class STFloatWU : STClass {
      [Transient] public static SodaTest st;
      internal Object i_float;
      
      public STFloatWU() : base() {
      }
      
      internal STFloatWU(float a_float) : base() {
         i_float = System.Convert.ToSingle(a_float);
      }
      
      public Object[] store() {
         return new Object[]{
            new STFloatWU(Single.MinValue),
new STFloatWU((float)1.23E-5),
new STFloatWU((float)1.345),
new STFloatWU(Single.MaxValue)         };
      }
      
      public void testEquals() {
         Query q1 = st.query();
         q1.constrain(store()[0]);
         st.expectOne(q1, store()[0]);
      }
      
      public void testGreater() {
         Query q1 = st.query();
         q1.constrain(new STFloatWU((float)0.1));
         q1.descend("i_float").constraints().greater();
         Object[] r1 = store();
         st.expect(q1, new Object[]{
            r1[2],
r1[3]         });
      }
      
      public void testSmaller() {
         Query q1 = st.query();
         q1.constrain(new STFloatWU((float)1.5));
         q1.descend("i_float").constraints().smaller();
         Object[] r1 = store();
         st.expect(q1, new Object[]{
            r1[0],
r1[1],
r1[2]         });
      }
   }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/soda/classes/wrapper/untyped/STFloatWU.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o;
using com.db4o.query;
using com.db4o.test.soda;
namespace com.db4o.test.soda.classes.wrapper.untyped {

   public class STFloatWU : STClass {
      [Transient] public static SodaTest st;
      internal Object i_float;
      
      public STFloatWU() : base() {
      }
      
      internal STFloatWU(float a_float) : base() {
         i_float = System.Convert.ToSingle(a_float);
      }
      
      public Object[] Store() {
         return new Object[]{
            new STFloatWU(Single.MinValue),
new STFloatWU((float)1.23E-5),
new STFloatWU((float)1.345),
new STFloatWU(Single.MaxValue)         };
      }
      
      public void TestEquals() {
         Query q1 = st.Query();
         q1.Constrain(Store()[0]);
         st.ExpectOne(q1, Store()[0]);
      }
      
      public void TestGreater() {
         Query q1 = st.Query();
         q1.Constrain(new STFloatWU((float)0.1));
         q1.Descend("i_float").Constraints().Greater();
         Object[] r1 = Store();
         st.Expect(q1, new Object[]{
            r1[2],
r1[3]         });
      }
      
      public void TestSmaller() {
         Query q1 = st.Query();
         q1.Constrain(new STFloatWU((float)1.5));
         q1.Descend("i_float").Constraints().Smaller();
         Object[] r1 = Store();
         st.Expect(q1, new Object[]{
            r1[0],
r1[1],
r1[2]         });
      }
   }
}
